@@ -63,6 +63,7 @@ sub requires {
 	'PPI::Document'	=> 1.117,
 	'PPI::Dumper'	=> 1.117,
 	'Scalar::Util'	=> 0,
+	'Text::Tabs'	=> 0,
 	'base'		=> 0,
 	'constant'	=> 0,
 	'strict'	=> 0,
@@ -166,7 +167,7 @@ information makes it into F<META.yml>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -174,7 +175,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016 by Thomas R. Wyant, III
+Copyright (C) 2016-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
